@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Clone::AUTHORITY = 'cpan:YANICK';
 }
 #ABSTRACT: Clone a CPAN module's history into a new git repository
-$Git::CPAN::Patch::Command::Clone::VERSION = '2.0.3';
+$Git::CPAN::Patch::Command::Clone::VERSION = '2.0.4';
 use 5.10.0;
 
 use strict;
@@ -22,11 +22,16 @@ parameter target => (
     required => 0,
 );
 
+has _seen_imports => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+);
+
 
 before [ qw/import_release clone_git_repo /] => method($release) {
-    state $first = 1;
-
-    return unless $first;
+    return if $self->_seen_imports;
+    $self->_set_seen_imports(1);
 
     my $target = $self->target || $release->dist_name;
 
@@ -35,13 +40,10 @@ before [ qw/import_release clone_git_repo /] => method($release) {
     dir($target)->mkpath;
     Git::Repository->run( init => $target );
     $self->set_root($target);
-
-    $first = 0;
 };
 
 after [ qw/ clone_git_repo import_release /] => method {
     $self->git_run( 'reset', '--hard', $self->last_commit );    
-    #$self->git_run( 'checkout', '-b', 'master', 'cpan/master' );
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -60,7 +62,7 @@ Git::CPAN::Patch::Command::Clone - Clone a CPAN module's history into a new git
 
 =head1 VERSION
 
-version 2.0.3
+version 2.0.4
 
 =head1 SYNOPSIS
 
@@ -101,7 +103,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yanick Champoux.
+This software is copyright (c) 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
