@@ -2,13 +2,14 @@ package Git::CPAN::Patch::Release;
 BEGIN {
   $Git::CPAN::Patch::Release::AUTHORITY = 'cpan:YANICK';
 }
-$Git::CPAN::Patch::Release::VERSION = '2.0.3';
+$Git::CPAN::Patch::Release::VERSION = '2.0.4';
 use strict;
 use warnings;
 
 use Method::Signatures::Simple;
 use File::chdir;
 use Archive::Any;
+use Path::Tiny;
 use File::Temp qw/ tempdir tempfile /;
 use version;
 
@@ -26,11 +27,17 @@ has author_name => (
         my $self = shift;
 
         if ( $self->meta_info ) {
-            my $author = $self->meta_info->{author};
+            my $author = $self->meta_info->{metadata}{author};
             $author = $author->[0] if ref $author;
-            return $1 if $author =~ /^\s*(.*?)\s*</;
+
+            if ( !$author or  $author eq 'unknown' ) {
+                $author = $self->meta_info->{author};
+            }
+            
+            return $author =~ /^\s*(.*?)\s*</ ? $1 : $author if $author;
         }
-        return 'unknown';
+
+        return $self->author_cpan || 'unknown';
     },
 );
 
@@ -39,12 +46,10 @@ has author_cpan => (
     isa => 'Maybe[Str]',
     lazy => 1,
     default => sub {
-        my $self = shift;
-        
-        no warnings 'uninitialized';
-        return uc $1 if $self->author_email =~ /(.*)\@cpan\.org$/;
-
-        return 'unknown@cpan.org';
+        my $author = eval{$_[0]->meta_info->{author}};
+        $author = ref $author ? $author->[0] : $author;
+        $author = uc($1) if $author =~ /<?(\S+)\@cpan\.org/i;
+        return $author;
     },
 );
 
@@ -57,11 +62,11 @@ has author_email => (
         my $self = shift;
         
         if ( $self->meta_info ) {
-            my $author = $self->meta_info->{author};
+            my $author = $self->meta_info->{metadata}{author} || $self->meta_info->{author};
             $author = $author->[0] if ref $author;
             return $1 if $author =~ /<(.*?)>\s*$/;
         }
-        return undef;
+        return $self->author_cpan . '@cpan.org';
     },
 );
 
@@ -154,15 +159,42 @@ has cpan_parse => (
     },
 );
 
+has metacpan => (
+    is => 'ro',
+    lazy => 1,
+    default => sub { 
+        require MetaCPAN::Client;
+        MetaCPAN::Client->new;
+    }
+);
+
 has meta_info => (
     is => 'ro',
     lazy => 1,
+    predicate => 'has_meta_info',
     default => method {
+        require MetaCPAN::Client;
+
+        if( my $release = $self->metacpan->release({ all => 
+                    [
+                        { distribution => $self->dist_name },
+                        { version => $self->dist_version },
+                    ]
+                }) ) {
+                $release = $release->next;
+                return $release->data if $release;
+            }
+
+        # TODO check on cpan if the info is not there
+
         require CPAN::Meta;
         
-        local $CWD = $self->extracted_dir;
-        return eval { CPAN::Meta->load_file('META.json') } 
-            || eval { CPAN::Meta->load_file('META.yml')  }; 
+        my( $result ) = map { CPAN::Meta->load_file($_) }
+                        grep { $_->exists }
+                        map { path( $self->extracted_dir )->child( "META.$_" ) } qw/ json yml /;
+
+        return $result;
+
     },
 );
 
@@ -170,7 +202,7 @@ has dist_version => (
     is => 'ro',
     lazy => 1,
     default => method {
-            $self->meta_info 
+            $self->has_meta_info 
                 ? $self->meta_info->{version} 
                 : $self->cpan_parse->distversion
     },
@@ -180,7 +212,7 @@ has dist_name => (
     is => 'ro',
     lazy => 1,
     default => method {
-        $self->meta_info 
+        $self->has_meta_info 
             ? $self->meta_info->{distribution} || $self->meta_info->{name}
             : $self->cpan_parse->dist
             ;
@@ -201,7 +233,7 @@ Git::CPAN::Patch::Release
 
 =head1 VERSION
 
-version 2.0.3
+version 2.0.4
 
 =head1 AUTHOR
 
@@ -209,7 +241,7 @@ Yanick Champoux <yanick@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yanick Champoux.
+This software is copyright (c) 2015 by Yanick Champoux.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
